.. scorched documentation master file, created by
   sphinx-quickstart on Wed Mar 12 21:48:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scorched's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   usage.rst
   query.rst
   mlt.rst
   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

